[Libreoffice-commits] core.git: sw/qa vcl/win

Tor Lillqvist tml at iki.fi
Wed Jul 31 03:47:07 PDT 2013


 sw/qa/extras/ooxmlexport/ooxmlexport.cxx |   30 ++++++++---------
 sw/qa/extras/ooxmlimport/ooxmlimport.cxx |    2 -
 sw/qa/extras/rtfexport/rtfexport.cxx     |   24 ++++++-------
 sw/qa/extras/rtfimport/rtfimport.cxx     |   12 +++---
 vcl/win/source/window/keynames.cxx       |   54 +++++++++++++++----------------
 5 files changed, 61 insertions(+), 61 deletions(-)

New commits:
commit 3e48277e36a485d964d7b91305b1bf70a83c4451
Author: Tor Lillqvist <tml at iki.fi>
Date:   Wed Jul 31 12:46:29 2013 +0200

    Convert utf-8 bytes to \xNN hex representation
    
    Change-Id: I5d1cc0331278f09a6e32345980c660d877d606fa

diff --git a/sw/qa/extras/ooxmlimport/ooxmlimport.cxx b/sw/qa/extras/ooxmlimport/ooxmlimport.cxx
index 0d10002..15bc845 100644
--- a/sw/qa/extras/ooxmlimport/ooxmlimport.cxx
+++ b/sw/qa/extras/ooxmlimport/ooxmlimport.cxx
@@ -948,7 +948,7 @@ void Test::testN779627()
 void Test::testFdo55187()
 {
     // 0x010d was imported as a newline.
-    getParagraph(1, OUString("lupčka", 7, RTL_TEXTENCODING_UTF8));
+    getParagraph(1, OUString("lup\xc4\x8dka", 7, RTL_TEXTENCODING_UTF8));
 }
 
 void Test::testN780563()
diff --git a/sw/qa/extras/rtfexport/rtfexport.cxx b/sw/qa/extras/rtfexport/rtfexport.cxx
index 48db195..3f062e2 100644
--- a/sw/qa/extras/rtfexport/rtfexport.cxx
+++ b/sw/qa/extras/rtfexport/rtfexport.cxx
@@ -279,14 +279,14 @@ void Test::testMathD()
 void Test::testMathEscaping()
 {
     OUString aActual = getFormula(getRun(getParagraph(1), 1));
-    OUString aExpected("á \\{", 5, RTL_TEXTENCODING_UTF8);
+    OUString aExpected("\xc3\xa1 \\{", 5, RTL_TEXTENCODING_UTF8);
     CPPUNIT_ASSERT_EQUAL(aExpected, aActual);
 }
 
 void Test::testMathLim()
 {
     OUString aActual = getFormula(getRun(getParagraph(1), 1));
-    OUString aExpected("lim from {x → 1} {x}", 22, RTL_TEXTENCODING_UTF8);
+    OUString aExpected("lim from {x \xe2\x86\x92 1} {x}", 22, RTL_TEXTENCODING_UTF8);
     CPPUNIT_ASSERT_EQUAL(aExpected, aActual);
 }
 
@@ -307,19 +307,19 @@ void Test::testMathBox()
 void Test::testMathMso2007()
 {
     OUString aActual = getFormula(getRun(getParagraph(1), 1));
-    OUString aExpected("A = π {r} ^ {2}", 16, RTL_TEXTENCODING_UTF8);
+    OUString aExpected("A = \xcf\x80 {r} ^ {2}", 16, RTL_TEXTENCODING_UTF8);
     CPPUNIT_ASSERT_EQUAL(aExpected, aActual);
 
     aActual = getFormula(getRun(getParagraph(2), 1));
-    aExpected = OUString("{left (x + a right )} ^ {n} = sum from {k = 0} to {n} {left (stack { n # k } right ) {x} ^ {k} {a} ^ {n − k}}", 111, RTL_TEXTENCODING_UTF8);
+    aExpected = OUString("{left (x + a right )} ^ {n} = sum from {k = 0} to {n} {left (stack { n # k } right ) {x} ^ {k} {a} ^ {n \xe2\x88\x92 k}}", 111, RTL_TEXTENCODING_UTF8);
     CPPUNIT_ASSERT_EQUAL(aExpected, aActual);
 
     aActual = getFormula(getRun(getParagraph(3), 1));
-    aExpected = OUString("{left (1 + x right )} ^ {n} = 1 + {nx} over {1 !} + {n left (n − 1 right ) {x} ^ {2}} over {2 !} + …", 104, RTL_TEXTENCODING_UTF8);
+    aExpected = OUString("{left (1 + x right )} ^ {n} = 1 + {nx} over {1 !} + {n left (n \xe2\x88\x92 1 right ) {x} ^ {2}} over {2 !} + \xe2\x80\xa6", 104, RTL_TEXTENCODING_UTF8);
     CPPUNIT_ASSERT_EQUAL(aExpected, aActual);
 
     aActual = getFormula(getRun(getParagraph(4), 1));
-    aExpected = OUString("f left (x right ) = {a} rsub {0} + sum from {n = 1} to {∞} {left ({a} rsub {n} cos {nπx} over {L} + {b} rsub {n} sin {nπx} over {L} right )}", 144,
+    aExpected = OUString("f left (x right ) = {a} rsub {0} + sum from {n = 1} to {\xe2\x88\x9e} {left ({a} rsub {n} cos {n\xcf\x80x} over {L} + {b} rsub {n} sin {n\xcf\x80x} over {L} right )}", 144,
             RTL_TEXTENCODING_UTF8);
     CPPUNIT_ASSERT_EQUAL(aExpected, aActual);
 
@@ -328,19 +328,19 @@ void Test::testMathMso2007()
     CPPUNIT_ASSERT_EQUAL(aExpected, aActual);
 
     aActual = getFormula(getRun(getParagraph(6), 1));
-    aExpected = OUString("x = {− b ± sqrt {{b} ^ {2} − 4 ac}} over {2 a}", 51, RTL_TEXTENCODING_UTF8);
+    aExpected = OUString("x = {\xe2\x88\x92 b \xc2\xb1 sqrt {{b} ^ {2} \xe2\x88\x92 4 ac}} over {2 a}", 51, RTL_TEXTENCODING_UTF8);
     CPPUNIT_ASSERT_EQUAL(aExpected, aActual);
 
     aActual = getFormula(getRun(getParagraph(7), 1));
-    aExpected = OUString("{e} ^ {x} = 1 + {x} over {1 !} + {{x} ^ {2}} over {2 !} + {{x} ^ {3}} over {3 !} + … , − ∞ < x < ∞", 106, RTL_TEXTENCODING_UTF8);
+    aExpected = OUString("{e} ^ {x} = 1 + {x} over {1 !} + {{x} ^ {2}} over {2 !} + {{x} ^ {3}} over {3 !} + \xe2\x80\xa6 , \xe2\x88\x92 \xe2\x88\x9e < x < \xe2\x88\x9e", 106, RTL_TEXTENCODING_UTF8);
     CPPUNIT_ASSERT_EQUAL(aExpected, aActual);
 
     aActual = getFormula(getRun(getParagraph(8), 1));
-    aExpected = OUString("sin α ± sin β = 2 sin {1} over {2} left (α ± β right ) cos {1} over {2} left (α ∓ β right )", 101, RTL_TEXTENCODING_UTF8);
+    aExpected = OUString("sin \xce\xb1 \xc2\xb1 sin \xce\xb2 = 2 sin {1} over {2} left (\xce\xb1 \xc2\xb1 \xce\xb2 right ) cos {1} over {2} left (\xce\xb1 \xe2\x88\x93 \xce\xb2 right )", 101, RTL_TEXTENCODING_UTF8);
     CPPUNIT_ASSERT_EQUAL(aExpected, aActual);
 
     aActual = getFormula(getRun(getParagraph(9), 1));
-    aExpected = OUString("cos α + cos β = 2 cos {1} over {2} left (α + β right ) cos {1} over {2} left (α − β right )", 99, RTL_TEXTENCODING_UTF8);
+    aExpected = OUString("cos \xce\xb1 + cos \xce\xb2 = 2 cos {1} over {2} left (\xce\xb1 + \xce\xb2 right ) cos {1} over {2} left (\xce\xb1 \xe2\x88\x92 \xce\xb2 right )", 99, RTL_TEXTENCODING_UTF8);
     CPPUNIT_ASSERT_EQUAL(aExpected, aActual);
 }
 
@@ -483,7 +483,7 @@ void Test::testFdo61507()
 
     uno::Reference<document::XDocumentPropertiesSupplier> xDocumentPropertiesSupplier(mxComponent, uno::UNO_QUERY);
     uno::Reference<document::XDocumentProperties> xDocumentProperties(xDocumentPropertiesSupplier->getDocumentProperties());
-    OUString aExpected = OUString("ÉÁŐŰ∭", 11, RTL_TEXTENCODING_UTF8);
+    OUString aExpected = OUString("\xc3\x89\xc3\x81\xc5\x90\xc5\xb0\xe2\x88\xad", 11, RTL_TEXTENCODING_UTF8);
     CPPUNIT_ASSERT_EQUAL(aExpected, xDocumentProperties->getTitle());
 
     // Only "Hello.", no additional characters.
@@ -513,7 +513,7 @@ void Test::testMnor()
 {
     // \mnor wasn't handled, leading to missing quotes around "divF" and so on.
     OUString aActual = getFormula(getRun(getParagraph(1), 1));
-    OUString aExpected("iiint from {V} to <?> {\"divF\"} dV = llint from {S} to <?> {\"F\" ∙ \"n\" dS}", 74, RTL_TEXTENCODING_UTF8);
+    OUString aExpected("iiint from {V} to <?> {\"divF\"} dV = llint from {S} to <?> {\"F\" \xe2\x88\x99 \"n\" dS}", 74, RTL_TEXTENCODING_UTF8);
     CPPUNIT_ASSERT_EQUAL(aExpected, aActual);
 }
 
diff --git a/sw/qa/extras/rtfimport/rtfimport.cxx b/sw/qa/extras/rtfimport/rtfimport.cxx
index c676d08..f1e12ba 100644
--- a/sw/qa/extras/rtfimport/rtfimport.cxx
+++ b/sw/qa/extras/rtfimport/rtfimport.cxx
@@ -547,7 +547,7 @@ void Test::testFdo45394()
     uno::Reference<text::XText> xHeaderText = getProperty< uno::Reference<text::XText> >(getStyles("PageStyles")->getByName(DEFAULT_STYLE), "HeaderText");
     OUString aActual = xHeaderText->getString();
     // Encoding in the header was wrong.
-    OUString aExpected("ПК РИК", 11, RTL_TEXTENCODING_UTF8);
+    OUString aExpected("\xd0\x9f\xd0\x9a \xd0\xa0\xd0\x98\xd0\x9a", 11, RTL_TEXTENCODING_UTF8);
     CPPUNIT_ASSERT_EQUAL(aExpected, aActual);
 
     uno::Reference<text::XTextTablesSupplier> xTextTablesSupplier(mxComponent, uno::UNO_QUERY);
@@ -574,7 +574,7 @@ void Test::testFdo45182()
     uno::Reference<container::XIndexAccess> xFootnotes(xFootnotesSupplier->getFootnotes(), uno::UNO_QUERY);
     uno::Reference<text::XTextRange> xTextRange(xFootnotes->getByIndex(0), uno::UNO_QUERY);
     // Encoding in the footnote was wrong.
-    OUString aExpected("živností", 10, RTL_TEXTENCODING_UTF8);
+    OUString aExpected("\xc5\xbeivnost\xc3\xad", 10, RTL_TEXTENCODING_UTF8);
     CPPUNIT_ASSERT_EQUAL(aExpected, xTextRange->getString());
 }
 
@@ -622,7 +622,7 @@ void Test::testFdo48023()
     uno::Reference<text::XTextRange> xTextRange = getRun(getParagraph(1), 1);
 
     // Implicit encoding detection based on locale was missing
-    OUString aExpected("Программист", 22, RTL_TEXTENCODING_UTF8);
+    OUString aExpected("\xd0\x9f\xd1\x80\xd0\xbe\xd0\xb3\xd1\x80\xd0\xb0\xd0\xbc\xd0\xbc\xd0\xb8\xd1\x81\xd1\x82", 22, RTL_TEXTENCODING_UTF8);
     CPPUNIT_ASSERT_EQUAL(aExpected, xTextRange->getString());
 }
 
@@ -644,7 +644,7 @@ void Test::testFdo44211()
 {
     uno::Reference<text::XTextRange> xTextRange = getRun(getParagraph(1), 1);
 
-    OUString aExpected("ąčę", 6, RTL_TEXTENCODING_UTF8);
+    OUString aExpected("\xc4\x85\xc4\x8d\xc4\x99", 6, RTL_TEXTENCODING_UTF8);
     CPPUNIT_ASSERT_EQUAL(aExpected, xTextRange->getString());
 }
 
@@ -833,7 +833,7 @@ void Test::testFdo49892()
 
 void Test::testFdo48446()
 {
-    OUString aExpected("Имя", 6, RTL_TEXTENCODING_UTF8);
+    OUString aExpected("\xd0\x98\xd0\xbc\xd1\x8f", 6, RTL_TEXTENCODING_UTF8);
     getParagraph(1, aExpected);
 }
 
@@ -1007,7 +1007,7 @@ void Test::testFdo56512()
     uno::Reference<text::XTextFramesSupplier> xTextFramesSupplier(mxComponent, uno::UNO_QUERY);
     uno::Reference<container::XIndexAccess> xIndexAccess(xTextFramesSupplier->getTextFrames(), uno::UNO_QUERY);
     uno::Reference<text::XTextRange> xTextRange(xIndexAccess->getByIndex(0), uno::UNO_QUERY);
-    OUString aExpected("עוסק מורשה ", 20, RTL_TEXTENCODING_UTF8);
+    OUString aExpected("\xd7\xa2\xd7\x95\xd7\xa1\xd7\xa7 \xd7\x9e\xd7\x95\xd7\xa8\xd7\xa9\xd7\x94 ", 20, RTL_TEXTENCODING_UTF8);
     CPPUNIT_ASSERT_EQUAL(aExpected, xTextRange->getString());
 }
 
diff --git a/vcl/win/source/window/keynames.cxx b/vcl/win/source/window/keynames.cxx
index c85360a..78ced0b 100644
--- a/vcl/win/source/window/keynames.cxx
+++ b/vcl/win/source/window/keynames.cxx
@@ -75,30 +75,30 @@ namespace vcl_sal {
         { PAPUGA_KEY_SPACEBAR, "Espaciu" },
         { PAPUGA_KEY_HOME, "Aniciu" },
         { PAPUGA_KEY_UP, "Arriba" },
-        { PAPUGA_KEY_PAGEUP, "Re Páx" },
+        { PAPUGA_KEY_PAGEUP, "Re P\xc3\xa1x" },
         { PAPUGA_KEY_LEFT, "Izquierda" },
         { PAPUGA_KEY_RIGHT, "Drecha" },
         { PAPUGA_KEY_END, "Fin" },
         { PAPUGA_KEY_DOWN, "Abaxo" },
-        { PAPUGA_KEY_PAGEDOWN, "Av Páx" },
+        { PAPUGA_KEY_PAGEDOWN, "Av P\xc3\xa1x" },
         { PAPUGA_KEY_INSERT, "Ins" },
         { PAPUGA_KEY_DELETE, "Supr" },
-        { PAPUGA_KEY_SHIFT, "Mayús" },
+        { PAPUGA_KEY_SHIFT, "May\xc3\xbas" },
     };
 
     static const struct KeysNameReplacement aImplReplacements_Catalan[] =
     {
-        { PAPUGA_KEY_BACK, "Retrocés" },
+        { PAPUGA_KEY_BACK, "Retroc\xc3\xa9s" },
         { PAPUGA_KEY_ENTER, "Retorn" },
         { PAPUGA_KEY_SPACEBAR, "Espai" },
         { PAPUGA_KEY_HOME, "Inici" },
         { PAPUGA_KEY_UP, "Amunt" },
-        { PAPUGA_KEY_PAGEUP, "Re Pàg" },
+        { PAPUGA_KEY_PAGEUP, "Re P\xc3\xa0g" },
         { PAPUGA_KEY_LEFT, "Esquerra" },
         { PAPUGA_KEY_RIGHT, "Dreta" },
         { PAPUGA_KEY_END, "Fi" },
         { PAPUGA_KEY_DOWN, "Avall" },
-        { PAPUGA_KEY_PAGEDOWN, "Av Pàg" },
+        { PAPUGA_KEY_PAGEDOWN, "Av P\xc3\xa0g" },
         { PAPUGA_KEY_INSERT, "Ins" },
         { PAPUGA_KEY_DELETE, "Supr" },
         { PAPUGA_KEY_SHIFT, "Maj" },
@@ -108,29 +108,29 @@ namespace vcl_sal {
     {
         { PAPUGA_KEY_RIGHT, "Nool paremale" },
         { PAPUGA_KEY_LEFT, "Nool vasakule" },
-        { PAPUGA_KEY_UP, "Nool üles" },
+        { PAPUGA_KEY_UP, "Nool \xc3\xbcles" },
         { PAPUGA_KEY_DOWN, "Nool alla" },
-        { PAPUGA_KEY_BACK, "Tagasilüke" },
+        { PAPUGA_KEY_BACK, "Tagasil\xc3\xbcke" },
         { PAPUGA_KEY_ENTER, "Enter" },
-        { PAPUGA_KEY_SPACEBAR, "Tühik" },
+        { PAPUGA_KEY_SPACEBAR, "T\xc3\xbchik" },
     };
 
     static const struct KeysNameReplacement aImplReplacements_Lithuanian[] =
     {
         { PAPUGA_KEY_ESC, "Gr" },
         { PAPUGA_KEY_BACK, "Naikinti" },
-        { PAPUGA_KEY_ENTER, "Įvesti" },
+        { PAPUGA_KEY_ENTER, "\xc4\xaevesti" },
         { PAPUGA_KEY_SPACEBAR, "Tarpas" },
         { PAPUGA_KEY_HOME, "Prad" },
-        { PAPUGA_KEY_UP, "Aukštyn" },
-        { PAPUGA_KEY_PAGEUP, "Psl↑" },
-        { PAPUGA_KEY_LEFT, "KairÄ—n" },
-        { PAPUGA_KEY_RIGHT, "Dešinėn" },
+        { PAPUGA_KEY_UP, "Auk\xc5\xa1tyn" },
+        { PAPUGA_KEY_PAGEUP, "Psl\xe2\x86\x91" },
+        { PAPUGA_KEY_LEFT, "Kair\xc4\x97n" },
+        { PAPUGA_KEY_RIGHT, "De\xc5\xa1in\xc4\x97n" },
         { PAPUGA_KEY_END, "Pab" },
-        { PAPUGA_KEY_DOWN, "Žemyn" },
-        { PAPUGA_KEY_PAGEDOWN, "Psl↓" },
-        { PAPUGA_KEY_INSERT, "Įterpti" },
-        { PAPUGA_KEY_DELETE, "Å al" },
+        { PAPUGA_KEY_DOWN, "\xc5\xbdemyn" },
+        { PAPUGA_KEY_PAGEDOWN, "Psl\xe2\x86\x93" },
+        { PAPUGA_KEY_INSERT, "\xc4\xaeterpti" },
+        { PAPUGA_KEY_DELETE, "\xc5\xa0al" },
         { PAPUGA_KEY_CONTROL, "Vald" },
         { PAPUGA_KEY_SHIFT, "Lyg2" },
         { PAPUGA_KEY_ALT, "Alt" },
@@ -138,13 +138,13 @@ namespace vcl_sal {
 
     static const struct KeysNameReplacement aImplReplacements_Slovenian[] =
     {
-        { PAPUGA_KEY_ESC, "Ubežnica" },
-        { PAPUGA_KEY_BACK, "Vračalka" },
-        { PAPUGA_KEY_ENTER, "Vnašalka" },
+        { PAPUGA_KEY_ESC, "Ube\xc5\xbenica" },
+        { PAPUGA_KEY_BACK, "Vra\xc4\x8dalka" },
+        { PAPUGA_KEY_ENTER, "Vna\xc5\xa1alka" },
         { PAPUGA_KEY_SPACEBAR, "Preslednica" },
-        { PAPUGA_KEY_HOME, "Začetek" },
+        { PAPUGA_KEY_HOME, "Za\xc4\x8detek" },
         { PAPUGA_KEY_UP, "Navzgor" },
-        { PAPUGA_KEY_PAGEUP, "Prejšnja stran" },
+        { PAPUGA_KEY_PAGEUP, "Prej\xc5\xa1nja stran" },
         { PAPUGA_KEY_LEFT, "Levo" },
         { PAPUGA_KEY_RIGHT, "Desno" },
         { PAPUGA_KEY_END, "Konec" },
@@ -164,15 +164,15 @@ namespace vcl_sal {
         { PAPUGA_KEY_SPACEBAR, "Espacio" },
         { PAPUGA_KEY_HOME, "Inicio" },
         { PAPUGA_KEY_UP, "Arriba" },
-        { PAPUGA_KEY_PAGEUP, "Re Pág" },
+        { PAPUGA_KEY_PAGEUP, "Re P\xc3\xa1g" },
         { PAPUGA_KEY_LEFT, "Izquierda" },
         { PAPUGA_KEY_RIGHT, "Derecha" },
         { PAPUGA_KEY_END, "Fin" },
         { PAPUGA_KEY_DOWN, "Abajo" },
-        { PAPUGA_KEY_PAGEDOWN, "Av Pág" },
+        { PAPUGA_KEY_PAGEDOWN, "Av P\xc3\xa1g" },
         { PAPUGA_KEY_INSERT, "Ins" },
         { PAPUGA_KEY_DELETE, "Supr" },
-        { PAPUGA_KEY_SHIFT, "Mayús" },
+        { PAPUGA_KEY_SHIFT, "May\xc3\xbas" },
     };
 
     static const struct KeysNameReplacement aImplReplacements_Hungarian[] =
@@ -182,7 +182,7 @@ namespace vcl_sal {
         { PAPUGA_KEY_UP, "Fel" },
         { PAPUGA_KEY_DOWN, "Le" },
         { PAPUGA_KEY_ENTER, "Enter" },
-        { PAPUGA_KEY_SPACEBAR, "Szóköz" },
+        { PAPUGA_KEY_SPACEBAR, "Sz\xc3\xb3k\xc3\xb6z" },
     };
 
     static const struct KeyboardReplacements aKeyboards[] =


More information about the Libreoffice-commits mailing list
diff --git a/sw/qa/extras/ooxmlexport/ooxmlexport.cxx b/sw/qa/extras/ooxmlexport/ooxmlexport.cxx
index b0f9845..f4932ff 100644
--- a/sw/qa/extras/ooxmlexport/ooxmlexport.cxx
+++ b/sw/qa/extras/ooxmlexport/ooxmlexport.cxx
@@ -350,8 +350,8 @@ void Test::testFdo51034()
 #define CHECK_FORMULA( expected, actual ) \
     CPPUNIT_ASSERT_EQUAL( \
         OUString( expected, strlen( expected ), RTL_TEXTENCODING_UTF8 ) \
-            .replaceAll( " ", "" ).replaceAll( OUString( "−", strlen( "−" ), RTL_TEXTENCODING_UTF8 ), "-" ), \
-        OUString( actual ).replaceAll( " ", "" ).replaceAll( OUString( "−", strlen( "−" ), RTL_TEXTENCODING_UTF8 ), "-" ))
+            .replaceAll( " ", "" ).replaceAll( OUString( "\xe2\x88\x92", strlen( "\xe2\x88\x92" ), RTL_TEXTENCODING_UTF8 ), "-" ), \
+        OUString( actual ).replaceAll( " ", "" ).replaceAll( OUString( "\xe2\x88\x92", strlen( "\xe2\x88\x92" ), RTL_TEXTENCODING_UTF8 ), "-" ))
 
 void Test::testMathAccents()
 {
@@ -376,12 +376,12 @@ void Test::testMathD()
 
 void Test::testMathEscaping()
 {
-    CHECK_FORMULA( "− ∞ < x < ∞", getFormula( getRun( getParagraph( 1 ), 1 )));
+    CHECK_FORMULA( "\xe2\x88\x92 \xe2\x88\x9e < x < \xe2\x88\x9e", getFormula( getRun( getParagraph( 1 ), 1 )));
 }
 
 void Test::testMathLim()
 {
-    CHECK_FORMULA( "lim from {x → 1} {x}", getFormula( getRun( getParagraph( 1 ), 1 )));
+    CHECK_FORMULA( "lim from {x \xe2\x86\x92 1} {x}", getFormula( getRun( getParagraph( 1 ), 1 )));
 }
 
 void Test::testMathMalformedXml()
@@ -396,32 +396,32 @@ void Test::testMathMatrix()
 
 void Test::testMathMso2k7()
 {
-    CHECK_FORMULA( "A = π {r} ^ {2}", getFormula( getRun( getParagraph( 1 ), 1 )));
+    CHECK_FORMULA( "A = \xcf\x80 {r} ^ {2}", getFormula( getRun( getParagraph( 1 ), 1 )));
 // TODO check the stack/binom difference
 //    CHECK_FORMULA( "{left (x+a right )} ^ {n} = sum from {k=0} to {n} {left (binom {n} {k} right ) {x} ^ {k} {a} ^ {n-k}}",
     CHECK_FORMULA( "{left (x+a right )} ^ {n} = sum from {k=0} to {n} {left (stack {n # k} right ) {x} ^ {k} {a} ^ {n-k}}",
         getFormula( getRun( getParagraph( 2 ), 1 )));
-    CHECK_FORMULA( "{left (1+x right )} ^ {n} =1+ {nx} over {1!} + {n left (n-1 right ) {x} ^ {2}} over {2!} +…",
+    CHECK_FORMULA( "{left (1+x right )} ^ {n} =1+ {nx} over {1!} + {n left (n-1 right ) {x} ^ {2}} over {2!} +\xe2\x80\xa6",
         getFormula( getRun( getParagraph( 3 ), 1 )));
 // TODO check (cos/sin miss {})
-//    CHECK_FORMULA( "f left (x right ) = {a} rsub {0} + sum from {n=1} to {∞} {left ({a} rsub {n} cos {{nπx} over {L}} + {b} rsub {n} sin {{nπx} over {L}} right )}",
-    CHECK_FORMULA( "f left (x right ) = {a} rsub {0} + sum from {n=1} to {∞} {left ({a} rsub {n} cos {nπx} over {L} + {b} rsub {n} sin {nπx} over {L} right )}",
+//    CHECK_FORMULA( "f left (x right ) = {a} rsub {0} + sum from {n=1} to {\xe2\x88\x9e} {left ({a} rsub {n} cos {{n\xcf\x80x} over {L}} + {b} rsub {n} sin {{n\xcf\x80x} over {L}} right )}",
+    CHECK_FORMULA( "f left (x right ) = {a} rsub {0} + sum from {n=1} to {\xe2\x88\x9e} {left ({a} rsub {n} cos {n\xcf\x80x} over {L} + {b} rsub {n} sin {n\xcf\x80x} over {L} right )}",
         getFormula( getRun( getParagraph( 4 ), 1 )));
     CHECK_FORMULA( "{a} ^ {2} + {b} ^ {2} = {c} ^ {2}", getFormula( getRun( getParagraph( 5 ), 1 )));
-    CHECK_FORMULA( "x = {- b ± sqrt {{b} ^ {2} -4 ac}} over {2 a}",
+    CHECK_FORMULA( "x = {- b \xc2\xb1 sqrt {{b} ^ {2} -4 ac}} over {2 a}",
         getFormula( getRun( getParagraph( 6 ), 1 )));
     CHECK_FORMULA(
-        "{e} ^ {x} =1+ {x} over {1!} + {{x} ^ {2}} over {2!} + {{x} ^ {3}} over {3!} +…,    -∞<x<∞",
+        "{e} ^ {x} =1+ {x} over {1!} + {{x} ^ {2}} over {2!} + {{x} ^ {3}} over {3!} +\xe2\x80\xa6,    -\xe2\x88\x9e<x<\xe2\x88\x9e",
         getFormula( getRun( getParagraph( 7 ), 1 )));
     CHECK_FORMULA(
-//        "sin {α} ± sin {β} =2 sin {{1} over {2} left (α±β right )} cos {{1} over {2} left (α∓β right )}",
+//        "sin {\xce\xb1} \xc2\xb1 sin {\xce\xb2} =2 sin {{1} over {2} left (\xce\xb1\xc2\xb1\xce\xb2 right )} cos {{1} over {2} left (\xce\xb1\xe2\x88\x93\xce\xb2 right )}",
 // TODO check (cos/in miss {})
-        "sin α ± sin β =2 sin {1} over {2} left (α±β right ) cos {1} over {2} left (α∓β right )",
+        "sin \xce\xb1 \xc2\xb1 sin \xce\xb2 =2 sin {1} over {2} left (\xce\xb1\xc2\xb1\xce\xb2 right ) cos {1} over {2} left (\xce\xb1\xe2\x88\x93\xce\xb2 right )",
         getFormula( getRun( getParagraph( 8 ), 1 )));
     CHECK_FORMULA(
 //        "cos {α} + cos {β} =2 cos {{1} over {2} left (α+β right )} cos {{1} over {2} left (α-β right )}",
 // TODO check (cos/sin miss {})
-        "cos α + cos β =2 cos {1} over {2} left (α+β right ) cos {1} over {2} left (α-β right )",
+        "cos \xce\xb1 + cos \xce\xb2 =2 cos {1} over {2} left (\xce\xb1+\xce\xb2 right ) cos {1} over {2} left (\xce\xb1-\xce\xb2 right )",
         getFormula( getRun( getParagraph( 9 ), 1 )));
 }
 
@@ -706,7 +706,7 @@ void Test::testTableStylerPrSz()
 
 void Test::testMathLiteral()
 {
-    CHECK_FORMULA( "iiint from {V} to <?> {\"div\" \"F\"}  dV= llint from {S} to <?> {\"F\" ∙ \"n \" dS}",
+    CHECK_FORMULA( "iiint from {V} to <?> {\"div\" \"F\"}  dV= llint from {S} to <?> {\"F\" \xe2\x88\x99 \"n \" dS}",
         getFormula( getRun( getParagraph( 1 ), 1 )));
 }
 
@@ -396,32 +396,32 @@ void Test::testMathMatrix()
         getFormula( getRun( getParagraph( 8 ), 1 )));
     CHECK_FORMULA(
-//        "cos {α} + cos {β} =2 cos {{1} over {2} left (α+β right )} cos {{1} over {2} left (α-β right )}",
+//        "cos {\xce\xb1} + cos {\xce\xb2} =2 cos {{1} over {2} left (\xce\xb1+\xce\xb2 right )} cos {{1} over {2} left (\xce\xb1-\xce\xb2 right )}",
 // TODO check (cos/sin miss {})